]> granicus.if.org Git - procps-ng/commitdiff
top: update some programmer documentation (no logic, just comments)
authorJim Warner <james.warner@comcast.net>
Thu, 29 Dec 2011 17:50:32 +0000 (11:50 -0600)
committerCraig Small <csmall@enc.com.au>
Tue, 3 Jan 2012 21:58:54 +0000 (08:58 +1100)
This commit corrects some outdated programmer comments.

Additionally, certain nls justifications might become
increasingly obscure with the passage of time so some
previous nls commit text has been added as comments.

top/top.c
top/top.h
top/top_nls.h

index 1d9ee5e4ac51e33b00dd4bceeed2de29d4c15d54..095ebe468ce6875ef43ef9ff6b30198200729e5a 100644 (file)
--- a/top/top.c
+++ b/top/top.c
@@ -1775,7 +1775,7 @@ always:
 /*######  Library Interface  #############################################*/
 
         /*
-         * This guy's modeled on libproc's 'five_cpu_numbers' function except
+         * This guy's modeled on libproc's 'eight_cpu_numbers' function except
          * we preserve all cpu data in our CPU_t array which is organized
          * as follows:
          *    cpus[0] thru cpus[n] == tics for each separate cpu
index 7f76b776a8a4b1f7f98de1a7acd845033daec743..c8d2fc8300c89967079318168ad903726abf645e 100644 (file)
--- a/top/top.h
+++ b/top/top.h
@@ -96,8 +96,8 @@
            -- mostly just to pinpoint source code usage/dependancies */
 #define SCREENMAX   512
    /* the above might seem pretty stingy, until you consider that with every
-      one of top's fields displayed it's less than 200 bytes of column header
-      -- so SCREENMAX provides for all fields plus a 300+ byte command line */
+      field displayed the column header would be approximately 250 bytes
+      -- so SCREENMAX provides for all fields plus a 250+ byte command line */
 #define CAPBUFSIZ    32
 #define CLRBUFSIZ    64
 #define PFLAGSSIZ    64
index 3f554e63e5fe4f340499c83ebe9c554591f200b6..a6d7c1f97be69f9fb5db2e40ca9a92a94305313f 100644 (file)
          *    Desc : field descriptions not to exceed 20 screen positions
          *    Norm : regular text possibly also containing c-format specifiers
          *    Uniq : show_special specially formatted strings
+         *
          * The latter table presents the greatest translation challenge !
+         *
+         * We go to the trouble of creating the nls string tables to achieve
+         * these objectives:
+         *    +  the overhead of repeated runtime calls to gettext()
+         *       will be avoided
+         *    +  the order of the strings in the template (.pot) file
+         *       can be completely controlled
+         *    +  none of the important translator only comments will
+         *       clutter and obscure the main program
          */
 extern const char *Desc_nlstab[];
 extern const char *Norm_nlstab[];